pub enum Error {
Http(Error),
Json(Error),
Api {
status: u16,
message: String,
},
AuthMismatch(String),
ServiceIdle,
ServiceStopped,
}Expand description
Errors that can occur when using the client.
Variants
Http(Error)
HTTP transport error.
Json(Error)
JSON serialization/deserialization error.
Api
API returned an error response.
AuthMismatch(String)
Operation requires a different auth mode than the client was configured with.
ServiceIdle
The Query API reported the service is idled and asked for an explicit
wake confirmation (HTTP 206 Confirm wake service). Retry the query
with wake_service set to wake the service and run it.
ServiceStopped
The Query API reported the service is stopped (HTTP 206 Service is stopped). A stopped service is never woken by the Query API; it must
be started explicitly.