pub struct ClickStackLogSourceResponse {Show 28 fields
pub body_expression: Option<String>,
pub connection: Option<String>,
pub default_table_select_expression: Option<String>,
pub disabled: Option<bool>,
pub displayed_timestamp_value_expression: Option<String>,
pub event_attributes_expression: Option<String>,
pub filter_settings: Option<ClickStackSourceFilterSettingsResponse>,
pub from: Option<ClickStackSourceFromResponse>,
pub highlighted_row_attribute_expressions: Option<Vec<ClickStackHighlightedAttributeExpressionResponse>>,
pub highlighted_trace_attribute_expressions: Option<Vec<ClickStackHighlightedAttributeExpressionResponse>>,
pub id: Option<String>,
pub implicit_column_expression: Option<String>,
pub kind: Option<ClickStackLogSourceKind>,
pub known_columns_list_expression: Option<String>,
pub materialized_views: Option<Vec<ClickStackMaterializedViewResponse>>,
pub metadata_materialized_views: Option<ClickStackLogSourceMetadataMaterializedViewsResponse>,
pub metric_source_id: Option<String>,
pub name: Option<String>,
pub query_settings: Option<Vec<ClickStackQuerySettingResponse>>,
pub resource_attributes_expression: Option<String>,
pub section: Option<String>,
pub service_name_expression: Option<String>,
pub severity_text_expression: Option<String>,
pub span_id_expression: Option<String>,
pub timestamp_value_expression: Option<String>,
pub trace_id_expression: Option<String>,
pub trace_source_id: Option<String>,
pub use_text_index_for_implicit_column: Option<ClickStackLogSourceUsetextindexforimplicitcolumn>,
}Expand description
ClickStackLogSource from the ClickHouse Cloud API, in response position.
Response variant of ClickStackLogSource: every field is Option<T>, so
a field the API drops or sends as null deserializes to None instead of
failing.
Fields
body_expression: Option<String>connection: Option<String>default_table_select_expression: Option<String>disabled: Option<bool>displayed_timestamp_value_expression: Option<String>event_attributes_expression: Option<String>filter_settings: Option<ClickStackSourceFilterSettingsResponse>from: Option<ClickStackSourceFromResponse>highlighted_row_attribute_expressions: Option<Vec<ClickStackHighlightedAttributeExpressionResponse>>highlighted_trace_attribute_expressions: Option<Vec<ClickStackHighlightedAttributeExpressionResponse>>id: Option<String>implicit_column_expression: Option<String>kind: Option<ClickStackLogSourceKind>known_columns_list_expression: Option<String>materialized_views: Option<Vec<ClickStackMaterializedViewResponse>>metadata_materialized_views: Option<ClickStackLogSourceMetadataMaterializedViewsResponse>metric_source_id: Option<String>name: Option<String>query_settings: Option<Vec<ClickStackQuerySettingResponse>>resource_attributes_expression: Option<String>section: Option<String>service_name_expression: Option<String>severity_text_expression: Option<String>span_id_expression: Option<String>timestamp_value_expression: Option<String>trace_id_expression: Option<String>trace_source_id: Option<String>use_text_index_for_implicit_column: Option<ClickStackLogSourceUsetextindexforimplicitcolumn>Trait Implementations
Sourceimpl Clone for ClickStackLogSourceResponse
impl Clone for ClickStackLogSourceResponse
Sourcefn clone(&self) -> ClickStackLogSourceResponse
fn clone(&self) -> ClickStackLogSourceResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClickStackLogSourceResponse
impl Debug for ClickStackLogSourceResponse
Sourceimpl Default for ClickStackLogSourceResponse
impl Default for ClickStackLogSourceResponse
Sourcefn default() -> ClickStackLogSourceResponse
fn default() -> ClickStackLogSourceResponse
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ClickStackLogSourceResponse
impl<'de> Deserialize<'de> for ClickStackLogSourceResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for ClickStackLogSourceResponse
Sourceimpl TryFrom<ClickStackLogSourceResponse> for ClickStackLogSource
impl TryFrom<ClickStackLogSourceResponse> for ClickStackLogSource
Sourcetype Error = MissingRequiredFields
type Error = MissingRequiredFields
The type returned in the event of a conversion error.