Module serde_helpers

Module serde_helpers 

Serde helpers used by generated models.

Functions

deserialize_or_raw
Deserialize a buffered payload into T, handing the payload back unchanged if it does not fit T.